@@ -76,6 +76,7 @@ sub setup_schema {
     open my $fh, '<:encoding(UTF-8)', $fname or die "$fname: $!";
     my $source = do { local $/; <$fh> };
     for my $stmt (split /;/, $source) {
+        next unless $stmt =~ /\S/;
         $dbh->do($stmt) or die $dbh->errstr();
     }
 }
@@ -83,75 +84,7 @@ sub setup_schema {
 1;
 ...
 
-    $self->write_file('lib/<<PATH>>/Web.pm', <<'...', { xslate => $self->create_view() });
-package <% $module %>::Web;
-use strict;
-use warnings;
-use utf8;
-use parent qw/<% $module %> Amon2::Web/;
-use File::Spec;
-
-# dispatcher
-use <% $module %>::Web::Dispatcher;
-sub dispatch {
-    return <% $module %>::Web::Dispatcher->dispatch($_[0]) or die "response is not generated";
-}
-
-<% $xslate %>
-
-# load plugins
-__PACKAGE__->load_plugins(
-    'Web::FillInFormLite',
-    'Web::CSRFDefender',
-);
-
-# for your security
-__PACKAGE__->add_trigger(
-    AFTER_DISPATCH => sub {
-        my ( $c, $res ) = @_;
-
-        # http://blogs.msdn.com/b/ie/archive/2008/07/02/ie8-security-part-v-comprehensive-protection.aspx
-        $res->header( 'X-Content-Type-Options' => 'nosniff' );
-
-        # http://blog.mozilla.com/security/2010/09/08/x-frame-options/
-        $res->header( 'X-Frame-Options' => 'DENY' );
-
-        # Cache control.
-        $res->header( 'Cache-Control' => 'private' );
-    },
-);
-
-__PACKAGE__->add_trigger(
-    BEFORE_DISPATCH => sub {
-        my ( $c ) = @_;
-        # ...
-        return;
-    },
-);
-
-1;
-...
-
-    $self->write_file("lib/<<PATH>>/Web/Dispatcher.pm", <<'...');
-package <% $module %>::Web::Dispatcher;
-use strict;
-use warnings;
-use utf8;
-use Amon2::Web::Dispatcher::Lite;
-
-any '/' => sub {
-    my ($c) = @_;
-    $c->render('index.tt');
-};
-
-post '/account/logout' => sub {
-    my ($c) = @_;
-    $c->session->expire();
-    $c->redirect('/');
-};
-
-1;
-...
+    $self->create_web_pms();
 
     $self->write_file('db/.gitignore', <<'...');
 *
@@ -559,6 +492,80 @@ sub write_status_file {
 ...
 }
 
+sub create_web_pms {
+    my ($self) = @_;
+
+    $self->write_file('lib/<<PATH>>/Web.pm', <<'...', { xslate => $self->create_view() });
+package <% $module %>::Web;
+use strict;
+use warnings;
+use utf8;
+use parent qw/<% $module %> Amon2::Web/;
+use File::Spec;
+
+# dispatcher
+use <% $module %>::Web::Dispatcher;
+sub dispatch {
+    return <% $module %>::Web::Dispatcher->dispatch($_[0]) or die "response is not generated";
+}
+
+<% $xslate %>
+
+# load plugins
+__PACKAGE__->load_plugins(
+    'Web::FillInFormLite',
+    'Web::CSRFDefender',
+);
+
+# for your security
+__PACKAGE__->add_trigger(
+    AFTER_DISPATCH => sub {
+        my ( $c, $res ) = @_;
+
+        # http://blogs.msdn.com/b/ie/archive/2008/07/02/ie8-security-part-v-comprehensive-protection.aspx
+        $res->header( 'X-Content-Type-Options' => 'nosniff' );
+
+        # http://blog.mozilla.com/security/2010/09/08/x-frame-options/
+        $res->header( 'X-Frame-Options' => 'DENY' );
+
+        # Cache control.
+        $res->header( 'Cache-Control' => 'private' );
+    },
+);
+
+__PACKAGE__->add_trigger(
+    BEFORE_DISPATCH => sub {
+        my ( $c ) = @_;
+        # ...
+        return;
+    },
+);
+
+1;
+...
+
+    $self->write_file("lib/<<PATH>>/Web/Dispatcher.pm", <<'...');
+package <% $module %>::Web::Dispatcher;
+use strict;
+use warnings;
+use utf8;
+use Amon2::Web::Dispatcher::Lite;
+
+any '/' => sub {
+    my ($c) = @_;
+    $c->render('index.tt');
+};
+
+post '/account/logout' => sub {
+    my ($c) = @_;
+    $c->session->expire();
+    $c->redirect('/');
+};
+
+1;
+...
+}
+
 sub create_makefile_pl {
     my ($self, $prereq_pm) = @_;
 
@@ -576,7 +583,6 @@ sub create_makefile_pl {
             'String::CamelCase'               => '0.02',
             'Amon2::DBI'                      => '0.06',
             'DBD::SQLite'                     => '1.33',
-            'Log::Minimal'                    => '0.06',
             'Test::WWW::Mechanize::PSGI'      => 0,
         },
     );
