@@ -120,6 +120,198 @@ builder {
 };
 ...
 
+    $self->write_file("lib/<<PATH>>/PC/C/Account.pm", <<'...');
+package <% $module %>::PC::C::Account;
+use strict;
+use warnings;
+use utf8;
+
+sub logout {
+    my ($class, $c) = @_;
+    $c->session->expire();
+    $c->redirect('/');
+}
+
+1;
+...
+
+    $self->write_file('tmpl/admin/index.tt', <<'...');
+[% WRAPPER 'include/layout.tt' %]
+
+<section>
+    <h1>This is a <% $dist %>'s admin site</h1>
+</section>
+
+[% END %]
+...
+
+    $self->write_file('tmpl/admin/include/layout.tt', <<'...');
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+<html xmlns="http://www.w3.org/1999/xhtml">
+<head>
+    <meta http-equiv="content-type" content="text/html; charset=utf-8" />
+    <title>[% title || '<%= $dist %>' %]</title>
+    <meta http-equiv="Content-Style-Type" content="text/css" />
+    <meta http-equiv="Content-Script-Type" content="text/javascript" />
+    <meta name="viewport" content="width=device-width, minimum-scale=1.0, maximum-scale=1.0"]]>
+    <meta name="format-detection" content="telephone=no" />
+    <% $tags %>
+    <link href="[% static_file('/static/css/admin.css') %]" rel="stylesheet" type="text/css" media="screen" />
+    <script src="[% static_file('/static/js/main.js') %]"></script>
+    <!--[if lt IE 9]>
+        <script src="http://html5shiv.googlecode.com/svn/trunk/html5.js"></script>
+    <![endif]-->
+</head>
+<body[% IF bodyID %] id="[% bodyID %]"[% END %]>
+    <div class="topbar-wrapper" style="z-index: 5;">
+        <div class="topbar">
+            <div class="topbar-inner">
+                <div class="container">
+                <h3><a href="#"><% $dist %></a></h3>
+                </div>
+            </div><!-- /topbar-inner -->
+        </div><!-- /topbar -->
+    </div>
+    <div class="container-fluid">
+        <div class="sidebar">
+                [% INCLUDE "include/sidebar.tt" %]
+        </div>
+        <div class="content">
+            [% content %]
+        </div>
+    </div>
+    <footer class="footer">
+        Powered by <a href="http://amon.64p.org/">Amon2</a>
+    </footer>
+</body>
+</html>
+...
+
+    $self->write_file('static/admin/css/admin.css', <<'...', {color1 => '#117711', color2 => '#119911'});
+body {
+    margin-top: 50px;
+}
+
+footer {
+    text-align: right;
+    padding-right: 10px;
+    padding-top: 2px; }
+    footer a {
+        text-decoration: none;
+        color: black;
+        font-weight: bold;
+    }
+
+/* smart phones */
+@media screen and (max-device-width: 480px) {
+}
+
+.topbar-inner,.topbar .fill{
+    background-color:<% color1 %>;
+    background-repeat:repeat-x;
+    background-image:-khtml-gradient(linear, left top, left bottom, from(<% color2 %>), to(<% color1 %>));
+    background-image:-moz-linear-gradient(top, <% color2 %>, <% color1 %>);
+    background-image:-ms-linear-gradient(top, <% color2 %>, <% color1 %>);
+    background-image:-webkit-gradient(linear, left top, left bottom, color-stop(0%, <% color2 %>), color-stop(100%, <% color1 %>));
+    background-image:-webkit-linear-gradient(top, <% color2 %>, <% color1 %>);
+    background-image:-o-linear-gradient(top, <% color2 %>, <% color1 %>);
+    background-image:linear-gradient(top, <% color2 %>, <% color1 %>);
+    filter:progid:DXImageTransform.Microsoft.gradient(startColorstr='<% color2 %>', endColorstr='<% color1 %>', GradientType=0);
+    -webkit-box-shadow:0 1px 3px rgba(0, 0, 0, 0.25),inset 0 -1px 0 rgba(0, 0, 0, 0.1);
+    -moz-box-shadow:0 1px 3px rgba(0, 0, 0, 0.25),inset 0 -1px 0 rgba(0, 0, 0, 0.1);
+    box-shadow:0 1px 3px rgba(0, 0, 0, 0.25),inset 0 -1px 0 rgba(0, 0, 0, 0.1);
+}
+...
+
+    $self->write_file('tmpl/admin/include/sidebar.tt', <<'...');
+<ul>
+    <li><a href="[% uri_for('/') %]">Home</a></li>
+</ul>
+...
+
+    $self->write_file("t/00_compile.t", <<'...');
+use strict;
+use warnings;
+use Test::More;
+
+use_ok $_ for qw(
+    <% $module %>
+    <% $module %>::PC
+    <% $module %>::PC::Dispatcher
+    <% $module %>::PC::C::Root
+    <% $module %>::PC::C::Account
+    <% $module %>::Admin
+    <% $module %>::Admin::Dispatcher
+    <% $module %>::Admin::C::Root
+);
+
+done_testing;
+...
+
+    $self->create_t_07_mech_links_t();
+
+    $self->write_file('t/04_admin.t', <<'...');
+use strict;
+use warnings;
+use utf8;
+use t::Util;
+use Plack::Test;
+use Plack::Util;
+use Test::More;
+
+my $app = Plack::Util::load_psgi 'app.psgi';
+test_psgi
+    app => $app,
+    client => sub {
+        my $cb = shift;
+
+        # 401
+        {
+            my $req = HTTP::Request->new(GET => "http://localhost/admin/");
+            my $res = $cb->($req);
+            is($res->code, 401, 'basic auth');
+        }
+
+        # 200
+        {
+            my $req = HTTP::Request->new(GET => "http://localhost/admin/");
+            $req->authorization_basic('admin', 'admin');
+            my $res = $cb->($req);
+            is($res->code, 200, 'basic auth');
+            like($res->content, qr{admin});
+        }
+    };
+
+my $admin = Plack::Util::load_psgi 'admin.psgi';
+test_psgi
+    app => $admin,
+    client => sub {
+        my $cb = shift;
+
+        # 401
+        {
+            my $req = HTTP::Request->new(GET => "http://localhost/");
+            my $res = $cb->($req);
+            is($res->code, 401, 'basic auth');
+        }
+
+        # 200
+        {
+            my $req = HTTP::Request->new(GET => "http://localhost/");
+            $req->authorization_basic('admin', 'admin');
+            my $res = $cb->($req);
+            is($res->code, 200, 'basic auth');
+            like($res->content, qr{admin});
+        }
+    };
+
+done_testing;
+...
+}
+
+sub create_web_pms {
+    my ($self) = @_;
+
     for my $moniker (qw(PC Admin)) {
         $self->write_file("lib/<<PATH>>/${moniker}.pm", <<'...', { xslate => $self->create_view(tmpl_path => 'tmpl/' . lc($moniker)), moniker => $moniker });
 package <% $module %>::<% $moniker %>;
@@ -231,137 +423,11 @@ sub index {
 ...
 
     }
-
-    $self->write_file("lib/<<PATH>>/PC/C/Account.pm", <<'...');
-package <% $module %>::PC::C::Account;
-use strict;
-use warnings;
-use utf8;
-
-sub logout {
-    my ($class, $c) = @_;
-    $c->session->expire();
-    $c->redirect('/');
 }
 
-1;
-...
-
-    $self->write_file('tmpl/admin/index.tt', <<'...');
-[% WRAPPER 'include/layout.tt' %]
-
-<section>
-    <h1>This is a <% $dist %>'s admin site</h1>
-</section>
-
-[% END %]
-...
-
-    $self->write_file('tmpl/admin/include/layout.tt', <<'...');
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml">
-<head>
-    <meta http-equiv="content-type" content="text/html; charset=utf-8" />
-    <title>[% title || '<%= $dist %>' %]</title>
-    <meta http-equiv="Content-Style-Type" content="text/css" />
-    <meta http-equiv="Content-Script-Type" content="text/javascript" />
-    <meta name="viewport" content="width=device-width, minimum-scale=1.0, maximum-scale=1.0"]]>
-    <meta name="format-detection" content="telephone=no" />
-    <link href="[% static_file('../static/bootstrap/bootstrap.min.css') %]" rel="stylesheet" type="text/css" />
-    <script src="[% static_file('../static/js/jquery-1.6.4.min.js') %]"></script>
-    <link href="[% static_file('/static/css/admin.css') %]" rel="stylesheet" type="text/css" media="screen" />
-    <script src="[% static_file('/static/js/main.js') %]"></script>
-    <!--[if lt IE 9]>
-        <script src="http://html5shiv.googlecode.com/svn/trunk/html5.js"></script>
-    <![endif]-->
-</head>
-<body[% IF bodyID %] id="[% bodyID %]"[% END %]>
-    <div class="topbar-wrapper" style="z-index: 5;">
-        <div class="topbar">
-            <div class="topbar-inner">
-                <div class="container">
-                <h3><a href="#"><% $dist %></a></h3>
-                </div>
-            </div><!-- /topbar-inner -->
-        </div><!-- /topbar -->
-    </div>
-    <div class="container-fluid">
-        <div class="sidebar">
-                [% INCLUDE "include/sidebar.tt" %]
-        </div>
-        <div class="content">
-            [% content %]
-        </div>
-    </div>
-    <footer class="footer">
-        Powered by <a href="http://amon.64p.org/">Amon2</a>
-    </footer>
-</body>
-</html>
-...
-
-    $self->write_file('static/admin/css/admin.css', <<'...', {color1 => '#117711', color2 => '#119911'});
-body {
-    margin-top: 50px;
-}
-
-footer {
-    text-align: right;
-    padding-right: 10px;
-    padding-top: 2px; }
-    footer a {
-        text-decoration: none;
-        color: black;
-        font-weight: bold;
-    }
-
-/* smart phones */
-@media screen and (max-device-width: 480px) {
-}
-
-.topbar-inner,.topbar .fill{
-    background-color:<% color1 %>;
-    background-repeat:repeat-x;
-    background-image:-khtml-gradient(linear, left top, left bottom, from(<% color2 %>), to(<% color1 %>));
-    background-image:-moz-linear-gradient(top, <% color2 %>, <% color1 %>);
-    background-image:-ms-linear-gradient(top, <% color2 %>, <% color1 %>);
-    background-image:-webkit-gradient(linear, left top, left bottom, color-stop(0%, <% color2 %>), color-stop(100%, <% color1 %>));
-    background-image:-webkit-linear-gradient(top, <% color2 %>, <% color1 %>);
-    background-image:-o-linear-gradient(top, <% color2 %>, <% color1 %>);
-    background-image:linear-gradient(top, <% color2 %>, <% color1 %>);
-    filter:progid:DXImageTransform.Microsoft.gradient(startColorstr='<% color2 %>', endColorstr='<% color1 %>', GradientType=0);
-    -webkit-box-shadow:0 1px 3px rgba(0, 0, 0, 0.25),inset 0 -1px 0 rgba(0, 0, 0, 0.1);
-    -moz-box-shadow:0 1px 3px rgba(0, 0, 0, 0.25),inset 0 -1px 0 rgba(0, 0, 0, 0.1);
-    box-shadow:0 1px 3px rgba(0, 0, 0, 0.25),inset 0 -1px 0 rgba(0, 0, 0, 0.1);
-}
-...
-
-    $self->write_file('tmpl/admin/include/sidebar.tt', <<'...');
-<ul>
-    <li><a href="[% uri_for('/') %]">Home</a></li>
-</ul>
-...
-
-    $self->write_file("t/00_compile.t", <<'...');
-use strict;
-use warnings;
-use Test::More;
-
-use_ok $_ for qw(
-    <% $module %>
-    <% $module %>::PC
-    <% $module %>::PC::Dispatcher
-    <% $module %>::PC::C::Root
-    <% $module %>::PC::C::Account
-    <% $module %>::Admin
-    <% $module %>::Admin::Dispatcher
-    <% $module %>::Admin::C::Root
-);
-
-done_testing;
-...
-
-    $self->write_file('t/04_admin.t', <<'...');
+sub create_t_07_mech_links_t {
+    my ($self, $more) = @_;
+    $self->write_file('t/07_mech_links.t', <<'...');
 use strict;
 use warnings;
 use utf8;
@@ -369,54 +435,46 @@ use t::Util;
 use Plack::Test;
 use Plack::Util;
 use Test::More;
+use Test::Requires 'Test::WWW::Mechanize::PSGI', 'HTML::TokeParser';
 
-my $app = Plack::Util::load_psgi 'app.psgi';
-test_psgi
-    app => $app,
-    client => sub {
-        my $cb = shift;
+my %link_tags = (
+    a      => 'href',
+    area   => 'href',
+    frame  => 'src',
+    iframe => 'src',
+    link   => 'href',
+    script => 'src',
+);
 
-        # 401
-        {
-            my $req = HTTP::Request->new(GET => "http://localhost/admin/");
-            my $res = $cb->($req);
-            is($res->code, 401, 'basic auth');
-        }
+sub _extract_links {
+    my $mech = shift;
 
-        # 200
-        {
-            my $req = HTTP::Request->new(GET => "http://localhost/admin/");
-            $req->authorization_basic('admin', 'admin');
-            my $res = $cb->($req);
-            is($res->code, 200, 'basic auth');
-            like($res->content, qr{admin});
+    my @links;
+    my $parser = HTML::TokeParser->new( \( $mech->content ) );
+    while ( my $token = $parser->get_tag( keys %link_tags ) ) {
+        push @links, $token->[1]->{ $link_tags{ $token->[0] } };
+    }
+    return grep { m{^/} } @links;
+}
+
+for (qw(app.psgi:/ admin.psgi:/ app.psgi:/admin/)) {
+    my ( $psgi, $root ) = split /:/, $_;
+    subtest $psgi => sub {
+        my $app = Plack::Util::load_psgi($psgi);
+
+        my $mech = Test::WWW::Mechanize::PSGI->new( app => $app );
+        $mech->credentials( 'admin', 'admin' );
+        $mech->get_ok($root);
+
+        my @links = _extract_links($mech);
+        for (@links) {
+            $mech->get($root);
+            $mech->get_ok($_);
         }
     };
+}
 
-my $admin = Plack::Util::load_psgi 'admin.psgi';
-test_psgi
-    app => $admin,
-    client => sub {
-        my $cb = shift;
-
-        # 401
-        {
-            my $req = HTTP::Request->new(GET => "http://localhost/");
-            my $res = $cb->($req);
-            is($res->code, 401, 'basic auth');
-        }
-
-        # 200
-        {
-            my $req = HTTP::Request->new(GET => "http://localhost/");
-            $req->authorization_basic('admin', 'admin');
-            my $res = $cb->($req);
-            is($res->code, 200, 'basic auth');
-            like($res->content, qr{admin});
-        }
-    };
-
-done_testing;
+done_testing();
 ...
 }
 
