@@ -26,34 +26,6 @@ sub load_config {
 1;
 ...
 
-    $self->write_file('lib/<<PATH>>/Web.pm', <<'...', { xslate => $self->create_view() });
-package <% $module %>::Web;
-use strict;
-use warnings;
-use utf8;
-use parent qw/<% $module %> Amon2::Web/;
-use File::Spec;
-
-# write your code here.
-sub dispatch {
-    my ($c) = @_;
-
-    $c->render('index.tt');
-}
-
-<% $xslate %>
-
-# for your security
-__PACKAGE__->add_trigger(
-    AFTER_DISPATCH => sub {
-        my ( $c, $res ) = @_;
-        $res->header( 'X-Content-Type-Options' => 'nosniff' );
-        $res->header( 'X-Frame-Options' => 'DENY' );
-    },
-);
-
-1;
-...
 
     $self->write_file('tmpl/index.tt', <<'...');
 <!doctype html>
@@ -84,6 +56,8 @@ builder {
 };
 ...
 
+    $self->create_web_pms();
+
     $self->create_makefile_pl();
 
     $self->write_file('t/00_compile.t', <<'...');
@@ -134,6 +108,39 @@ all_pod_files_ok();
 ...
 }
 
+sub create_web_pms {
+    my ($self) = @_;
+
+    $self->write_file('lib/<<PATH>>/Web.pm', <<'...', { xslate => $self->create_view() });
+package <% $module %>::Web;
+use strict;
+use warnings;
+use utf8;
+use parent qw/<% $module %> Amon2::Web/;
+use File::Spec;
+
+# write your code here.
+sub dispatch {
+    my ($c) = @_;
+
+    $c->render('index.tt');
+}
+
+<% $xslate %>
+
+# for your security
+__PACKAGE__->add_trigger(
+    AFTER_DISPATCH => sub {
+        my ( $c, $res ) = @_;
+        $res->header( 'X-Content-Type-Options' => 'nosniff' );
+        $res->header( 'X-Frame-Options' => 'DENY' );
+    },
+);
+
+1;
+...
+}
+
 sub create_t_02_mech_t {
     my ($self, $more) = @_;
     $more ||= '';
